@@ -226,6 +226,7 @@ NAMES = {
     '.bash_aliases': EXTENSIONS['bash'],
     '.bash_profile': EXTENSIONS['bash'],
     '.bashrc': EXTENSIONS['bash'],
+    '.bazelrc': {'text', 'bazelrc'},
     '.bowerrc': EXTENSIONS['json'] | {'bowerrc'},
     '.browserslistrc': {'text', 'browserslistrc'},
     '.clang-format': EXTENSIONS['yaml'],
@@ -251,7 +252,11 @@ NAMES = {
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
     '.rstcheck.cfg': EXTENSIONS['ini'],
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
+    '.zlogin': EXTENSIONS['zsh'],
+    '.zlogout': EXTENSIONS['zsh'],
+    '.zprofile': EXTENSIONS['zsh'],
     '.zshrc': EXTENSIONS['zsh'],
+    '.zshenv': EXTENSIONS['zsh'],
     'AUTHORS': EXTENSIONS['txt'],
     'BUILD': {'text', 'bazel'},
     'BUILD.bazel': {'text', 'bazel'},
